/// <reference types="node" />
import { EventEmitter } from 'events';
import { GoogleAuthOptions } from 'google-auth-library';
import { cloudbuild_v1 } from 'googleapis';
export declare enum ProgressEvent {
    CREATING_BUCKET = "CREATING_BUCKET",
    UPLOADING = "UPLOADING",
    BUILDING = "BUILDING",
    COMPLETE = "COMPLETE",
    LOG = "LOG"
}
export interface BuildOptions extends GoogleAuthOptions {
    /**
     * The path to the container sources.
     * Defaults to CWD if not defined.
     */
    sourcePath?: string;
    /**
     * The path to the yaml/json config.
     * Defaults to `${sourcePath}/cloudbuild.yaml`
     */
    configPath?: string;
    /**
     * The docker tag to apply to the container that gets created.
     */
    tag?: string;
}
/**
 * Class that provides the `deploy` method.
 */
export declare class Builder extends EventEmitter {
    private sourcePath;
    private configPath?;
    private tag?;
    private _auth;
    private gcb;
    private gcs;
    constructor(options?: BuildOptions);
    /**
     * Deploy the current application using the given opts.
     */
    build(): Promise<BuildResult>;
    /**
     * Obtain the full text of the log after the build is complete.
     * At some point this should be replaced with streaming logs.
     * @param result The BuildResult returned from the create operation
     */
    private fetchLog;
    /**
     * Given an operation, poll it until complete.
     * @private
     * @param name Fully qualified name of the operation.
     */
    private poll;
    /**
     * Upload a local file to GCS given a signed url
     * @private
     * @param localPath Fully qualified path to the zip on disk.
     * @param remotePath Signed url used to put the file to
     */
    private upload;
    /**
     * Look in the CWD for a `.gcloudignore` file.  If one is present, parse it,
     * and return the ignore rules as an array of strings.
     * @private
     */
    private getIgnoreRules;
}
export declare function build(options: BuildOptions): Promise<BuildResult>;
export interface BuildResult {
    name: string;
    log: string;
    metadata: {
        build: cloudbuild_v1.Schema$Build;
    };
}
export interface BuildError extends Error {
    log?: string;
}
